import request from '@/utils/request'

// 查询指标分类列表
export function listNORM(query) {
  return request({
    url: '/norm/list',
    method: 'get',
    params: query
  })
}

// 查询指标分类所有列表
export function listAllNORM(query) {
  return request({
    url: '/norm/listAll',
    method: 'get',
    params: query
  })
}

// 查询指标分类详细
export function getNORM(id) {
  return request({
    url: '/norm/getInfo/' + id,
    method: 'get'
  })
}

// 新增指标分类
export function addNORM(data) {
  return request({
    url: '/norm/add',
    method: 'post',
    data: data
  })
}

// 修改指标分类
export function updateNORM(data) {
  return request({
    url: '/norm/edit',
    method: 'post',
    data: data
  })
}

// 删除指标分类
export function delNORM(id) {
  return request({
    url: '/norm/remove/' + id,
    method: 'get'
  })
}

// 删除指标分类
export function exportNORM(id) {
  return request({
    url: '/norm/export',
    method: 'post'
  })
}